###########################################################################
## This 'tangle' R script was created from an RSP document.
## RSP source document: 'incl/example.txt.rsp'
## Metadata 'title': 'RSP Markup Language - Reference Card'
## Metadata 'keywords': 'RSP markup language, Quick Reference Card'
## Metadata 'author': 'Henrik Bengtsson'
## Metadata 'engine': 'R.rsp::rsp'
## Metadata 'tangle': 'FALSE'
###########################################################################

R.rsp <- R.oo::Package("R.rsp");
R.rsp$version
R.rsp$author
format(as.Date(R.rsp$date), format="%B %d, %Y")
for (i in 1:3) {
i
}
R.rsp$version
R.rsp$date
